@@ -175,28 +175,20 @@ class MetricsExtractor:
                 "Are you sure you want to delete %s?" % self.tmpdir
             ):
                 return
+        shutil.rmtree(self.tmpdir)
 
-            # GitHub actions appears to have race condition
-            try:
-                shutil.rmtree(self.tmpdir)
-            except:
-                logger.error("Issue cleaning up %s" % self.tmpdir)
-                pass
-
-    def extract_all(self, versions=None):
-        versions = versions or []
+    def extract_all(self):
         for name in self.metrics:
-            self.extract_metric(name, versions)
+            self.extract_metric(name)
 
-    def extract_metric(self, name, versions=None):
+    def extract_metric(self, name):
         """Given a metric, extract for each commit from the repository."""
-        versions = versions or []
         if name not in self.metrics:
             logger.exit("Metric %s is not known." % name)
 
         # If no git repository defined, prepare one
         if not self.git:
-            self.prepare_repository(versions)
+            self.prepare_repository()
 
         module, metric_name = self._metrics[name].rsplit(".", 1)
         metric = self.get_metric(name)
@@ -208,13 +200,12 @@ class MetricsExtractor:
         module, metric_name = self._metrics[name].rsplit(".", 1)
         return getattr(importlib.import_module(module), metric_name)(self.git)
 
-    def prepare_repository(self, versions=None):
+    def prepare_repository(self):
         """Since most source code archives won't include the git history,
         we would want to create a root directly with a new git installation,
         and then create tagged commits that correpond to each version. We
         can then use this git repository to derive metrics of change.
         """
-        versions = versions or []
         if not self.manager:
             logger.exit("A manager is required to prepare a repository.")
 
@@ -227,12 +218,8 @@ class MetricsExtractor:
         # Initialize empty respository
         self.git.init()
 
-        # If we have versions, filter down
-        self.filter_versions(versions)
-
         # For each version, download and create git commit and tag
         for i, spec in enumerate(self.manager.specs):
-
             logger.info(
                 "Downloading and tagging %s, %s of %s"
                 % (spec["version"], i + 1, len(self.manager.specs))
@@ -258,17 +245,6 @@ class MetricsExtractor:
         logger.info("Repository for %s is created at %s" % (self.manager, self.tmpdir))
         return self.git
 
-    def filter_versions(self, versions=None):
-        """Given a list of versions, filter down the specs to only include
-        the ones in the list
-        """
-        if versions:
-            specs = []
-            for spec in self.manager.specs:
-                if spec["version"] in versions:
-                    specs.append(spec)
-            self.manager._specs = specs
-
     def save_all(self, outdir, force=False, fmt=None):
         """Save data as json or zip exports using an outdir root. If fmt is None,
         we use the extractor default (typically single-json except for metrics
